Quick Start / Most Users
========================

Start here if you want to run analyses through the workflow system or
configuration files with minimal setup. This path emphasizes end-to-end
runs, practical configuration choices, and reproducible execution.

If you need API-level customization or want to build workflows
programmatically, go to :doc:`../developer/index`.

Getting Started
---------------

.. toctree::
   :maxdepth: 2

   ../getting_started/installation
   ../getting_started/quickstart
   ../guides/migration_scipy
   ../migration/curve_fit_to_fit

Workflow-Based Analysis
-----------------------

.. toctree::
   :maxdepth: 2

   workflow_overview
   common_workflows
   ../guides/practical_workflows
   ../guides/large_datasets
   ../guides/streaming_optimizer_comparison

Configuration Guide
-------------------

.. toctree::
   :maxdepth: 2

   yaml_configuration
   ../guides/workflow_options
   ../guides/stability
   ../guides/defense_layers
   ../guides/performance_guide

Results & Outputs
-----------------

.. toctree::
   :maxdepth: 2

   results_outputs

Troubleshooting
---------------

.. toctree::
   :maxdepth: 2

   ../guides/troubleshooting
   ../migration/streaming_fault_tolerance
